django-sites
============

Alternative implementation of django "sites" framework based on
settings instead of models.


How to install?
---------------

You can install it with pip:

.. code-block:: shell

    pip install django-sites

Documentation
-------------

https://django-sites.readthedocs.org/en/latest/
